@@ -1,28 +1,38 @@
+import logging
+from typing import Dict
 from zephyrus_sc2_parser.events.base_event import BaseEvent
 
+logger = logging.getLogger(__name__)
+
 
 class PlayerStatsEvent(BaseEvent):
-    def __init__(self, summary_stats, *args):
+    def __init__(self, summary_stats: Dict, *args):
         super().__init__(*args)
-        self.summary_stats = summary_stats
+        self.summary_stats: Dict = summary_stats
 
-    def parse_event(self):
-        player = self.player
-        gameloop = self.event['_gameloop']
+    def parse_event(self) -> Dict:
         event = self.event
+        player = self.player
+        gameloop = self.gameloop
+        game = self.game
         summary_stats = self.summary_stats
 
+        logger.debug(f'Parsing {self.type} at {gameloop}')
+
         if not player:
+            logger.debug('No player associated with this event')
             return
 
-        self.player.supply = event['m_stats']['m_scoreValueFoodUsed'] // 4096
-        self.player.supply_cap = event['m_stats']['m_scoreValueFoodMade'] // 4096
+        logger.debug(f'Player: {player.name} ({player.player_id})')
 
-        if gameloop != self.game.game_length:
-            if self.player.supply >= self.player.supply_cap:
-                self.player.supply_block += 112
+        player.supply = event['m_stats']['m_scoreValueFoodUsed'] // 4096
+        player.supply_cap = event['m_stats']['m_scoreValueFoodMade'] // 4096
 
-        self.player.resources_collected['minerals'] = (
+        if gameloop != game.game_length:
+            if player.supply >= player.supply_cap:
+                player.supply_block += 112
+
+        player.resources_collected['minerals'] = (
             event['m_stats']['m_scoreValueMineralsCurrent'] +
             event['m_stats']['m_scoreValueMineralsUsedInProgressArmy'] +
             event['m_stats']['m_scoreValueMineralsUsedInProgressEconomy'] +
@@ -35,7 +45,7 @@ class PlayerStatsEvent(BaseEvent):
             event['m_stats']['m_scoreValueMineralsLostTechnology']
         )
 
-        self.player.resources_collected['gas'] = (
+        player.resources_collected['gas'] = (
             event['m_stats']['m_scoreValueVespeneCurrent'] +
             event['m_stats']['m_scoreValueVespeneUsedInProgressArmy'] +
             event['m_stats']['m_scoreValueVespeneUsedInProgressEconomy'] +
@@ -48,8 +58,8 @@ class PlayerStatsEvent(BaseEvent):
             event['m_stats']['m_scoreValueVespeneLostTechnology']
         )
 
-        unspent_resources = self.player.unspent_resources
-        collection_rate = self.player.collection_rate
+        unspent_resources = player.unspent_resources
+        collection_rate = player.collection_rate
 
         if gameloop != 1:
             unspent_resources['minerals'].append(
@@ -66,7 +76,7 @@ class PlayerStatsEvent(BaseEvent):
                 event['m_stats']['m_scoreValueVespeneCollectionRate']
             )
 
-        if gameloop == self.game.game_length:
+        if gameloop == game.game_length:
             summary_stats['supply_block'][player.player_id] = round(self.player.supply_block / 22.4, 1)
 
             summary_stats['resources_lost']['minerals'][player.player_id] = event['m_stats']['m_scoreValueMineralsLostArmy']
@@ -75,27 +85,59 @@ class PlayerStatsEvent(BaseEvent):
             summary_stats['resources_collected']['minerals'][player.player_id] = self.player.resources_collected['minerals']
             summary_stats['resources_collected']['gas'][player.player_id] = self.player.resources_collected['gas']
 
+            # ----- unspent resources -----
+
             player_minerals = unspent_resources['minerals']
             player_gas = unspent_resources['gas']
-            summary_stats['avg_unspent_resources']['minerals'][player.player_id] = round(
-                sum(player_minerals)/len(player_minerals), 1
-            )
-            summary_stats['avg_unspent_resources']['gas'][player.player_id] = round(
-                sum(player_gas)/len(player_gas), 1
-            )
+
+            if len(player_minerals) == 0:
+                summary_stats['avg_unspent_resources']['minerals'][player.player_id] = 0
+            else:
+                summary_stats['avg_unspent_resources']['minerals'][player.player_id] = round(
+                    sum(player_minerals) / len(player_minerals), 1
+                )
+
+            if len(player_gas) == 0:
+                summary_stats['avg_unspent_resources']['gas'][player.player_id] = 0
+            else:
+                summary_stats['avg_unspent_resources']['gas'][player.player_id] = round(
+                    sum(player_gas) / len(player_gas), 1
+                )
+
+            # ----- collection rates -----
 
             player_minerals_collection = collection_rate['minerals']
             player_gas_collection = collection_rate['gas']
-            summary_stats['avg_resource_collection_rate']['minerals'][player.player_id] = round(
-                sum(player_minerals_collection)/len(player_minerals_collection), 1
+
+            if len(player_minerals_collection) == 0:
+                summary_stats['avg_resource_collection_rate']['minerals'][player.player_id] = 0
+            else:
+                summary_stats['avg_resource_collection_rate']['minerals'][player.player_id] = round(
+                    sum(player_minerals_collection) / len(player_minerals_collection), 1
+                )
+
+            if len(player_gas_collection) == 0:
+                summary_stats['avg_resource_collection_rate']['gas'][player.player_id] = 0
+            else:
+                summary_stats['avg_resource_collection_rate']['gas'][player.player_id] = round(
+                    sum(player_gas_collection) / len(player_gas_collection), 1
+                )
+
+            total_collection_rate = (
+                summary_stats['avg_resource_collection_rate']['minerals'][player.player_id]
+                + summary_stats['avg_resource_collection_rate']['gas'][player.player_id]
             )
-            summary_stats['avg_resource_collection_rate']['gas'][player.player_id] = round(
-                sum(player_gas_collection)/len(player_gas_collection), 1
+            total_avg_unspent = (
+                summary_stats['avg_unspent_resources']['minerals'][player.player_id]
+                + summary_stats['avg_unspent_resources']['gas'][player.player_id]
             )
 
-            total_collection_rate = summary_stats['avg_resource_collection_rate']['minerals'][player.player_id] + summary_stats['avg_resource_collection_rate']['gas'][player.player_id]
-            total_avg_unspent = summary_stats['avg_unspent_resources']['minerals'][player.player_id] + summary_stats['avg_unspent_resources']['gas'][player.player_id]
-            player_sq = player.calc_sq(unspent_resources=total_avg_unspent, collection_rate=total_collection_rate)
+            # ----- other stats -----
+
+            player_sq = player.calc_sq(
+                unspent_resources=total_avg_unspent,
+                collection_rate=total_collection_rate,
+            )
             summary_stats['sq'][player.player_id] = player_sq
 
             current_workers = event['m_stats']['m_scoreValueWorkersActiveCount']
