@@ -1,4 +1,8 @@
+import logging
 from zephyrus_sc2_parser.events.base_event import BaseEvent
+from zephyrus_sc2_parser.dataclasses import Upgrade
+
+logger = logging.getLogger(__name__)
 
 
 class UpgradeEvent(BaseEvent):
@@ -6,9 +10,13 @@ class UpgradeEvent(BaseEvent):
         super().__init__(*args)
 
     def parse_event(self):
-        player = self.player
         event = self.event
-        upgrades = self.game.gamedata['upgrades']
+        player = self.player
+        gameloop = self.gameloop
+        upgrades = self.game.gamedata.upgrades
+
+        logger.debug(f'Parsing {self.type} at {gameloop}')
+        logger.debug(f'Player: {player.name} ({player.player_id})')
 
         lowercase_upgrades = {
             'zerglingmovementspeed': 'ZerglingMovementSpeed',
@@ -23,4 +31,7 @@ class UpgradeEvent(BaseEvent):
             upgrade_name = lowercase_upgrades[event['m_upgradeTypeName'].decode('utf-8')]
 
         if upgrade_name:
-            player.upgrades.append(upgrade_name)
+            logger.debug(f'Adding upgrade: {upgrade_name} to player')
+            player.upgrades.append(Upgrade(upgrade_name, gameloop))
+        else:
+            logger.warning(f'Unknown upgrade: {event["m_upgradeTypeName"].decode("utf-8")}')
